@@ -14,6 +14,11 @@ use Mojo::Base -base;
 
 =head1 ATTRIBUTES
 
+=head2 builder
+
+Returns a code-ref or method name for building the default value for this
+field or undef unless a builder was not defined.
+
 =head2 name
 
 Returns the name.
@@ -24,6 +29,7 @@ Returns the type specified as "isa" in the constructor.
 
 =cut
 
+sub builder { shift->{builder} }
 sub name { shift->{name} }
 sub type_constraint { shift->{isa} }
 
